#
from enigma import *
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.InputBox import InputBox
from Screens.ChoiceBox import ChoiceBox
from Components.ActionMap import ActionMap, NumberActionMap
from Components.ScrollLabel import ScrollLabel
from Components.GUIComponent import *
from Components.MenuList import MenuList
from Components.Input import Input
from Screens.Console import Console
from Plugins.Plugin import PluginDescriptor
from Screens.ImageWizard import ImageWizard
from Plugins.Plugin import PluginDescriptor

import os

###############################################################################

er_path = "/usr/lib/enigma2/python/Plugins/Extensions/DM7025remote"
er_script = "/usr/lib/enigma2/python/Plugins/Extensions/DM7025remote/er.sh"
er_readme = "/usr/lib/enigma2/python/Plugins/Extensions/DM7025remote/readme.txt"
er_startup = "/etc/rc3.d/S22mediaserver"

###############################################################################
# versionstring
###############################################################################
er_pluginversion = "V4.0"

###############################################################################
def main(session,**kwargs):
    try:    
     	session.open(Er)
    except:
        print "[RC] Pluginexecution failed"
###############################################################################
def autostart(reason,**kwargs):
    if reason == 0:
        print "[RC] no autostart"
###############################################################################
def Plugins(**kwargs):
    return PluginDescriptor(
        name="DM 7025 Remote Control", 
        description="plugin for Remote Control management", 
        where = PluginDescriptor.WHERE_PLUGINMENU,
        fnc = main
        )
###############################################################################
###############################################################################
class Er(Screen):
    skin = """
        <screen position="100,100" size="500,400" title="Remote Control Menu" >
            <widget name="menu" position="10,10" size="490,390" scrollbarMode="showOnDemand" />
        </screen>"""
        
    def __init__(self, session, args = 0):
        self.skin = Er.skin
        self.session = session
        Screen.__init__(self, session)
        self.menu = args
        list = []
        list.append((_("info if Mediaserver is running"), "info"))        
        list.append((_("restart options"), "restartwizzard"))
        if os.path.exists(er_startup) == False:
           list.append((_("install options - enable here first !"), "installwizzard"))        
        else:
           list.append((_("install options"), "installwizzard"))        
        list.append((_("display logfile"), "log"))        
        list.append((_("change password"), "passwd"))        
        list.append((_("change Webserver port"), "port"))        
        list.append((_("help"), "help"))        
        list.append((_("man"), "man"))        
        list.append((_("about"), "about"))        
        self["menu"] = MenuList(list)
        self["actions"] = ActionMap(["WizardActions", "DirectionActions"],{"ok": self.go,"back": self.close,}, -1)
        
    def go(self):
        returnValue = self["menu"].l.getCurrentSelection()[1]
        if returnValue is not None:
           if returnValue is "info":
             self.session.open(Console,_("showing RC Info"),["%s info" % er_script])
           elif returnValue is "restartwizzard":
               RestartWizzard(self.session)
           elif returnValue is "installwizzard":
               InstallWizzard(self.session)
           elif returnValue is "man":
             self.session.open(Console,_("man shows readme.txt of RC"),["%s man" % er_script])
           elif returnValue is "passwd":
               PasswordWizzard(self.session)
           elif returnValue is "port":
               PortWizzard(self.session)
           elif returnValue is "log":
             self.session.open(Console,_("displaying logfile of Mediaserver"),["%s log" % er_script])
           elif returnValue is "help":
             self.session.open(Console,_("short help on RC commands"),["%s" % er_script])
           elif returnValue is "about":
             self.session.open(MessageBox,_("Remote Control Enigma2 Plugin %s\n\nRC tool by thowi\n\nMediaserver by 3c5x9\n\nEnjoy Remote Controlling DM 7025 !" % er_pluginversion), MessageBox.TYPE_INFO)



###############################################################################
###############################################################################


class InstallWizzard(Screen):
    def __init__(self, session):
        self.session = session
        self.askForInstall()
        
    def askForInstall(self):
            self.session.openWithCallback(self.askForCommand,ChoiceBox,"select install command to be executed",self.getCommandList())

    def askForCommand(self,source):
        if source is None:
            self.skipInstall("no command passed, skipping install")
        else:
            self.source = source [1]
            self.session.openWithCallback(self.installCommand,MessageBox,"are you sure to install with %s" % self.source, MessageBox.TYPE_YESNO)
            
    def installCommand(self,answer):
        if answer is None:
            self.skipInstall("answer is None")
        if answer is False:
            self.skipInstall("you were not confirming")
        else:
            self.session.open(Console,"executing install command",["%s %s" % (er_script,self.source)])
            
    def skipInstall(self,reason):
        self.session.open(MessageBox,"install was canceled, because %s" % reason, MessageBox.TYPE_WARNING)
        
    def getCommandList(self):
        images = []
        images.append(("enable  Mediaserver daemon","enable"))
        images.append(("disable Mediaserver daemon","disable"))
        return images
        
###############################################################################
###############################################################################

class RestartWizzard(Screen):
    def __init__(self, session):
        self.session = session
        self.askForRestart()
        
    def askForRestart(self):
            self.session.openWithCallback(self.askForCommand,ChoiceBox,"select restart command to be executed",self.getCommandList())

    def askForCommand(self,source):
        if source is None:
            self.skipRestart("no command passed, skipping restart")
        else:
            self.source = source [1]
            self.session.openWithCallback(self.restartCommand,MessageBox,"are you sure to %s" % self.source, MessageBox.TYPE_YESNO)
            
    def restartCommand(self,answer):
        if answer is None:
            self.skipRestart("answer is None")
        if answer is False:
            self.skipRestart("you were not confirming")
        else:
            title = "executing command on Dreambox"
            cmd = "%s %s"  % (er_script,self.source)
            self.session.open(Console,title,[cmd])
            
    def skipRestart(self,reason):
        self.session.open(MessageBox,"restart was canceled, because %s" % reason, MessageBox.TYPE_WARNING)
        
    def getCommandList(self):
        images = []
        images.append(("info if Mediaserver dameon is running","info"))
        images.append(("start   Mediaserver daemon","start"))
        images.append(("stop    Mediaserver daemon","stop"))
        images.append(("restart Mediaserver dameon","restart"))
        images.append(("reboot  Dreambox","reboot"))
        images.append(("halt    Dreambox","halt"))
        images.append(("restart Enigma2 on Dreambox","kill"))
        return images

###############################################################################
###############################################################################

class PasswordWizzard(Screen):
    def __init__(self, session):
        self.session = session
        self.askForPassword()
        
    def askForPassword(self):
	self.session.openWithCallback(self.processingPassword,InputBox, title="Please enter new Password for WebIF login", text="thowi", maxSize=False, type=Input.TEXT)

    def processingPassword(self,password):
        if password is None:
            self.password="thowi";
        else:
            self.password = password
        title="are you sure to change password to: %s" % self.password
        self.session.openWithCallback(self.PasswordChange,MessageBox,"%s" % title, MessageBox.TYPE_YESNO)

    def PasswordChange(self,answer):
        if answer is None:
            self.skipPassword("answer is No")
        if answer is False:
            self.skipPassword("you were not confirming")
        else:
            title = "changing password to: %s" % self.password
            cmd = "%s passwd %s" % (er_script,self.password)
            self.session.open(Console,title,[cmd])
            
    def skipPassword(self,reason):
        self.session.open(MessageBox,"password change was canceled, because %s" % reason, MessageBox.TYPE_WARNING)
        


class PortWizzard(Screen):
    def __init__(self, session):
        self.session = session
        self.askForPort()
        
    def askForPort(self):
	self.session.openWithCallback(self.processingPort,InputBox, title="Please enter Webserver port for Mediaserver", text="80", maxSize=False, type=Input.TEXT)


    def processingPort(self,port):
        if port is None:
            self.port="80";
        else:
            self.port = port
        title="are you sure to change Webserver port to: %s" % self.port
        self.session.openWithCallback(self.PortChange,MessageBox,"%s" % title, MessageBox.TYPE_YESNO)

    def PortChange(self,answer):
        if answer is None:
            self.skipPort("answer is No")
        if answer is False:
            self.skipPort("you were not confirming")
        else:
            title = "changing Webserver port to: %s" % self.port
            cmd = "%s port %s" % (er_script,self.port)
            self.session.open(Console,title,[cmd])
            
    def skipPort(self,reason):
        self.session.open(MessageBox,"Webserver port change was canceled, because %s" % reason, MessageBox.TYPE_WARNING)
        


